import axios from 'axios';
import { ListParams, queryList } from '@/api/list';
import qs from 'query-string';

export interface PermissionCreateRecord {
  module: string;
  title: string;
  code: string;
  remark: string;
}
export interface PermissionRecord extends PermissionCreateRecord {
  id: number | undefined;
}
export interface PermissionTreeRecord extends PermissionCreateRecord {
  id: number;
  parentId: number;
  children?: PermissionTreeRecord[];
}

export function listToTree(nodes: any[]): any[] {
  const map: { [id: number]: any } = {};
  const result: any[] = [];
  nodes.forEach((item) => {
    map[item.id] = item;
  });
  nodes.forEach((item) => {
    const parent = map[item.parentId];
    if (parent) {
      if (!parent.children) {
        parent.children = [];
      }
      parent.children.push(item);
    } else {
      result.push(item);
    }
  });
  return result;
}

export function create(data: PermissionCreateRecord) {
  return axios.post(`/api/permission`, data);
}

export function update(data: PermissionRecord) {
  return axios.patch(`/api/permission/${data.id}`, data);
}

export function getDetail(id: number) {
  return axios.get<PermissionRecord>(`/api/permission/${id}`);
}

export function remove(id: number) {
  return axios.delete(`/api/permission/${id}`);
}
export function list(params?: Partial<PermissionRecord>) {
  return axios.get<PermissionTreeRecord[]>(`/api/permission/all`, {
    params,
    paramsSerializer: (obj) => {
      return qs.stringify(obj);
    },
  });
}

export function queryPermissions(
  params?: ListParams<Partial<PermissionRecord>>
) {
  return queryList<PermissionRecord>(`/api/permission`, params);
}
