import axios from 'axios';

export interface TicketCreateRecord {
  title: string;
  body: string;
  money: undefined;
  type: string;
  contactEmail: string;
  companyName: string;
  attachId: string;
  auditorId: string;
  submit: boolean;
  userId: undefined;
}

export interface TicketRecord extends TicketCreateRecord {
  value: any;
  id: undefined;
  status: string
}
export interface auditRecord {
  auditorId: string;
  comment: string;
  result: string;
  ticketId: string;
}

export function queryTicket(data: any) {
  return axios({
    url: '/api/rest/bill', // 路径
    method: 'get',
    params: data, // 参数
  });
}

export function getDetail(id: string) {
  return axios.get(`/api/rest/bill/${id}`);
}


// 更新票据
export function update(data: TicketRecord) {
  return axios.patch(`/api/rest/bill/${data.id}`, data);
}

// 删除票据
export function remove(id: string) {
  return axios.delete(`/api/rest/bill?id=${id}`);
}

// 添加票据
export function create(params: TicketCreateRecord) {
  return axios.post('/api/rest/bill', params);
}

// 上传附件
export function uploadFile(file: any) {
  return axios.post('/api/rest/attachment', file);
}

// 获取附件信息
export function attachment(id:string){
  return axios.get(`/api/rest/attachment/find/${id}`)
}

// 审核
export function audit(ticketId: string, params: auditRecord) {
  return axios.patch(`/api/rest/bill/audit/${ticketId}`, params); 
}

// 审核员管理的票据列表
export function auditTickctList(data: any){
  return axios({
    url: '/api/rest/bill/audit/list', // 路径
    method: 'get',
    params: data, // 参数
  });
}

